#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

install_requires = \
['typer[all] == 0.3.2',
 'Markdown == 3.3.4',
 'Jinja2 == 2.11.3',
 'chardet == 4.0.0',
 'python-markdown-math == 0.8',
 'attributedict == 0.3.0']

entry_points = \
{'console_scripts': ['simplewiki = wikiserver:main']}

setup(name='pysimplewiki',
      version='0.1.2',
      description='Simple Wiki - это вики движок, отображающий файловую структуру в веб-энциклопедию; поддерживает статьи в форматах .html, .md. Simple Wiki написана на языке python, поддерживает гибкое расширение и стилизацию.',
      author='baterflyrity',
      author_email='baterflyrity@yandex.ru',
      url='https://github.com/baterflyrity/pysimplewiki',
      py_modules=['wikiserver'],
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='~=3.8',
     )
